# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-11-15 14:55
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('lp_accounts', '0004_auto_20171031_1627'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='type',
        ),
    ]
